@@ -1046,9 +1046,9 @@ public class PhpType {
     return global(context.getProject());
   }
 
-  public PhpType global(@NotNull Project p) {
+  public PhpType global(@NotNull Project p, int currentRecursionDepth) {
     try {
-      return PhpIndex.getInstance(p).completeType(p, this, null);
+      return PhpIndex.getInstance(p).completeType(p, this, null, currentRecursionDepth);
     }
     catch (StackOverflowError e) {
       if (ApplicationManager.getApplication().isUnitTestMode()) {
@@ -1060,6 +1060,10 @@ public class PhpType {
     }
   }
 
+  public PhpType global(@NotNull Project p) {
+    return global(p, 0);
+  }
+
   public boolean isEmpty() {
     return types == null || types.isEmpty();
   }
